"use strict";

require("core-js/modules/es7.symbol.async-iterator");

require("core-js/modules/es6.symbol");

require("core-js/modules/web.dom.iterable");

require("core-js/modules/es6.array.for-each");

require("core-js/modules/es6.array.index-of");

require("core-js/modules/es6.array.map");

var fs = require("fs");

var path = require("path");

var chalk = require('chalk');

var conf = require("./config");

var _require = require('./utils'),
    capitalize = _require.capitalize;

var _require2 = require('./template'),
    indexContent = _require2.indexContent,
    mapPropsContent = _require2.mapPropsContent,
    pContent = _require2.pContent,
    lessContent = _require2.lessContent,
    servicesContent = _require2.servicesContent,
    modelsContent = _require2.modelsContent;

var DIRS = ["models", "services", "components"];

function Main(argv) {
  var files = argv._;

  if (files.length > 0) {
    files.map(function (file) {
      start(file);
      return null;
    });
  } else {
    var msg = chalk.yellow("\u8BF7\u8F93\u5165\u8981\u521B\u5EFA\u7684\u6A21\u5757\u540D\u79F0\uFF01\uFF01\uFF01");
    console.info(msg); // eslint-disable-line
  }
}

function start(file) {
  if (file.length) {
    var root = "./";

    if (isExisDir(conf.root)) {
      root = conf.root || "./";
    } // 获取 root 下面的所有文件夹


    var pagesPath = path.resolve(process.cwd(), root);
    var allDirs = findDirs(pagesPath);

    if (allDirs.indexOf(file) > -1) {
      var msg = chalk.yellow("".concat(file, " \u6587\u4EF6\u5939\u5DF2\u7ECF\u5B58\u5728\uFF0C\u8BF7\u91CD\u547D\u540D\u8F93\u5165\uFF01\uFF01\uFF01"));
      console.info(msg); // eslint-disable-line

      return;
    }

    var filePath = path.resolve(process.cwd(), root, file);
    var pageName = "".concat(capitalize(file), "Page"); // 创建目录

    DIRS.forEach(function (dirName) {
      mkdirsSync("".concat(filePath, "/").concat(dirName));
    }); // 创建文件，写入内容
    // index.js

    writeFile("".concat(filePath, "/index.js"), indexContent(pageName)); // MapProps.js

    writeFile("".concat(filePath, "/MapProps.js"), mapPropsContent(pageName, file)); // xxxPage.js

    writeFile("".concat(filePath, "/").concat(pageName, ".js"), pContent(pageName)); // xxxPage.less

    writeFile("".concat(filePath, "/").concat(pageName, ".less"), lessContent()); // services

    writeFile("".concat(filePath, "/services/").concat(file, ".js"), servicesContent(file)); // models

    writeFile("".concat(filePath, "/models/").concat(file, ".js"), modelsContent(file), true);
  }
} // 检查某个目录是否存在


function isExisDir(dir) {
  try {
    var stat = fs.statSync(dir);

    if (stat) {
      return true;
    }
  } catch (error) {
    return false;
  }

  return false;
} // 获取所有子目录


function findDirs(dirs) {
  var dirArr = [];
  var dirArray = fs.readdirSync(dirs);
  var _iteratorNormalCompletion = true;
  var _didIteratorError = false;
  var _iteratorError = undefined;

  try {
    for (var _iterator = dirArray[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
      var d = _step.value;
      var filePath = path.resolve(dirs, d);
      var stat = fs.statSync(filePath);

      if (stat.isDirectory()) {
        dirArr.push(d);
      }
    }
  } catch (err) {
    _didIteratorError = true;
    _iteratorError = err;
  } finally {
    try {
      if (!_iteratorNormalCompletion && _iterator["return"] != null) {
        _iterator["return"]();
      }
    } finally {
      if (_didIteratorError) {
        throw _iteratorError;
      }
    }
  }

  return dirArr;
} // 递归创建目录 同步方法


function mkdirsSync(dirname) {
  if (fs.existsSync(dirname)) {
    return true;
  } else if (mkdirsSync(path.dirname(dirname))) {
    fs.mkdirSync(dirname);
    return true;
  }
} // 创建文件


function writeFile(filename) {
  var fileContent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
  var flag = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : false;
  fs.writeFile(filename, fileContent, 'utf8', function (error) {
    if (error) {
      var err = chalk.red(error);
      console.info(err); // eslint-disable-line

      return false;
    }

    if (flag) {
      var msg = chalk.green("模块创建成功！！！");
      console.info(msg); // eslint-disable-line

      return true;
    }
  });
}

module.exports = Main;